==> webkit2gtk_2.48.5.orig.tar.xz: webkitgtk-2.48.5/Source/WebCore/rendering/MotionPath.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "FloatRoundedRect.h"
#include "RenderLayerModelObject.h"

namespace WebCore {

class BoxPathOperation;
class RenderElement;
class PathOperation;
class RayPathOperation;
class ShapePathOperation;

struct TransformOperationData;

struct MotionPathData {
    FloatRoundedRect containingBlockBoundingRect;
    FloatPoint offsetFromContainingBlock;
    FloatPoint usedStartingPosition;
};

class MotionPath {
public:
    static std::optional<MotionPathData> motionPathDataForRenderer(const RenderElement&);
    static bool needsUpdateAfterContainingBlockLayout(const PathOperation&);

    static void applyMotionPathTransform(TransformationMatrix&, const TransformOperationData&, const FloatPoint& transformOrigin, const PathOperation&, const LengthPoint& offsetAnchor, const Length& offsetDistance, const OffsetRotation&, TransformBox);
    static void applyMotionPathTransform(const RenderStyle&, const TransformOperationData&, TransformationMatrix&);

    static std::optional<Path> computePathForBox(const BoxPathOperation&, const TransformOperationData&);
    static std::optional<Path> computePathForShape(const ShapePathOperation&, const TransformOperationData&);
    static std::optional<Path> computePathForRay(const RayPathOperation&, const TransformOperationData&);
};

} // namespace WebCore

==> webkit2gtk_2.50.4.orig.tar.xz: webkitgtk-2.50.4/Source/WebCore/rendering/MotionPath.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "FloatRoundedRect.h"
#include "RenderLayerModelObject.h"

namespace WebCore {

class BoxPathOperation;
class RenderElement;
class PathOperation;
class RayPathOperation;
class ShapePathOperation;

struct TransformOperationData;

struct MotionPathData {
    FloatRoundedRect containingBlockBoundingRect;
    FloatPoint offsetFromContainingBlock;
    FloatPoint usedStartingPosition;
};

class MotionPath {
public:
    static std::optional<MotionPathData> motionPathDataForRenderer(const RenderElement&);
    static bool needsUpdateAfterContainingBlockLayout(const Style::OffsetPath&);

    static void applyMotionPathTransform(TransformationMatrix&, const TransformOperationData&, const FloatPoint& transformOrigin, const Style::OffsetPath&, const Style::OffsetAnchor&, const Style::OffsetDistance&, const Style::OffsetRotate&, TransformBox);
    static void applyMotionPathTransform(const RenderStyle&, const TransformOperationData&, TransformationMatrix&);

    static std::optional<Path> computePathForBox(const BoxPathOperation&, const TransformOperationData&);
    static std::optional<Path> computePathForShape(const ShapePathOperation&, const TransformOperationData&);
    static std::optional<Path> computePathForRay(const RayPathOperation&, const TransformOperationData&);
};

} // namespace WebCore
